public inbox for archer-commits@sourceware.org
help / color / mirror / Atom feed
From: jkratoch@sourceware.org
To: archer-commits@sourceware.org
Subject: [SCM]  archer-jankratochvil-absdir: Merge branch 'locsymtab-dos-isabs-macfullname-config-all-priv' into locsymtab-dos-isabs-macfullname-config-all-priv-annotate
Date: Tue, 25 Dec 2012 17:00:00 -0000	[thread overview]
Message-ID: <20121225170010.18767.qmail@sourceware.org> (raw)

The branch, archer-jankratochvil-absdir has been updated
       via  6add25a872441b58aab65c7820c2c25f213374c7 (commit)
       via  4e9b5eaadeaec65db6435b075c1299a4c1f3c824 (commit)
       via  ec27c383222674879fb10a33cfa936c89d1807b4 (commit)
       via  4ee4bb1f217e7290b21930fda172f5d553a81135 (commit)
       via  3e320f2c3e93c5b502c7bf7bad1dda630797e57b (commit)
      from  bc106774f1c4ce4dc6edd460ef9106efafe316fe (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email.

- Log -----------------------------------------------------------------
commit 6add25a872441b58aab65c7820c2c25f213374c7
Merge: bc10677 4e9b5ea
Author: Jan Kratochvil <jan.kratochvil@redhat.com>
Date:   Tue Dec 25 17:59:22 2012 +0100

    Merge branch 'locsymtab-dos-isabs-macfullname-config-all-priv' into locsymtab-dos-isabs-macfullname-config-all-priv-annotate

commit 4e9b5eaadeaec65db6435b075c1299a4c1f3c824
Merge: 18622dd ec27c38
Author: Jan Kratochvil <jan.kratochvil@redhat.com>
Date:   Tue Dec 25 17:58:54 2012 +0100

    Merge branch 'locsymtab-dos-isabs-macfullname-config-all' into locsymtab-dos-isabs-macfullname-config-all-priv

commit ec27c383222674879fb10a33cfa936c89d1807b4
Merge: b69ed75 4ee4bb1
Author: Jan Kratochvil <jan.kratochvil@redhat.com>
Date:   Tue Dec 25 17:58:30 2012 +0100

    Merge branch 'locsymtab-dos-isabs-macfullname-config' into locsymtab-dos-isabs-macfullname-config-all

commit 4ee4bb1f217e7290b21930fda172f5d553a81135
Merge: 8f9e961 3e320f2
Author: Jan Kratochvil <jan.kratochvil@redhat.com>
Date:   Tue Dec 25 17:58:02 2012 +0100

    Merge branch 'locsymtab-dos-isabs-macfullname' into locsymtab-dos-isabs-macfullname-config

commit 3e320f2c3e93c5b502c7bf7bad1dda630797e57b
Author: Jan Kratochvil <jan.kratochvil@redhat.com>
Date:   Tue Dec 25 17:56:52 2012 +0100

    .

-----------------------------------------------------------------------

Summary of changes:
 gdb/macrocmd.c |    4 ++--
 gdb/macrotab.c |   42 +++++++++++++++++++++---------------------
 gdb/macrotab.h |   27 ++++++++++++++-------------
 3 files changed, 37 insertions(+), 36 deletions(-)

First 500 lines of diff:
diff --git a/gdb/macrocmd.c b/gdb/macrocmd.c
index a327cad..f6f0d2b 100644
--- a/gdb/macrocmd.c
+++ b/gdb/macrocmd.c
@@ -131,12 +131,12 @@ show_pp_source_pos (struct ui_file *stream,
                     struct macro_source_file *file,
                     int line)
 {
-  fprintf_filtered (stream, "%s:%d\n", file->filename, line);
+  fprintf_filtered (stream, "%s:%d\n", file->fullname, line);
 
   while (file->included_by)
     {
       fprintf_filtered (gdb_stdout, "  included at %s:%d\n",
-                        file->included_by->filename,
+                        file->included_by->fullname,
                         file->included_at_line);
       file = file->included_by;
     }
diff --git a/gdb/macrotab.c b/gdb/macrotab.c
index 6154362..1eabded 100644
--- a/gdb/macrotab.c
+++ b/gdb/macrotab.c
@@ -380,14 +380,14 @@ macro_tree_delete_key (void *untyped_key)
 /* Allocate and initialize a new source file structure.  */
 static struct macro_source_file *
 new_source_file (struct macro_table *t,
-                 const char *filename)
+                 const char *fullname)
 {
   /* Get space for the source file structure itself.  */
   struct macro_source_file *f = macro_alloc (sizeof (*f), t);
 
   memset (f, 0, sizeof (*f));
   f->table = t;
-  f->filename = macro_bcache_str (t, filename);
+  f->fullname = macro_bcache_str (t, fullname);
   f->includes = 0;
 
   return f;
@@ -407,20 +407,20 @@ free_macro_source_file (struct macro_source_file *src)
       free_macro_source_file (child);
     }
 
-  macro_bcache_free (src->table, (char *) src->filename);
+  macro_bcache_free (src->table, (char *) src->fullname);
   macro_free (src, src->table);
 }
 
 
 struct macro_source_file *
 macro_set_main (struct macro_table *t,
-                const char *filename)
+                const char *fullname)
 {
   /* You can't change a table's main source file.  What would that do
      to the tree?  */
   gdb_assert (! t->main_source);
 
-  t->main_source = new_source_file (t, filename);
+  t->main_source = new_source_file (t, fullname);
 
   return t->main_source;
 }
@@ -446,7 +446,7 @@ macro_allow_redefinitions (struct macro_table *t)
 struct macro_source_file *
 macro_include (struct macro_source_file *source,
                int line,
-               const char *included)
+               const char *included_fullname)
 {
   struct macro_source_file *new;
   struct macro_source_file **link;
@@ -472,7 +472,7 @@ macro_include (struct macro_source_file *source,
          First, squawk.  */
       complaint (&symfile_complaints,
 		 _("both `%s' and `%s' allegedly #included at %s:%d"),
-		 included, (*link)->filename, source->filename, line);
+		 included_fullname, (*link)->fullname, source->fullname, line);
 
       /* Now, choose a new, unoccupied line number for this
          #inclusion, after the alleged #inclusion line.  */
@@ -487,7 +487,7 @@ macro_include (struct macro_source_file *source,
   /* At this point, we know that LINE is an unused line number, and
      *LINK points to the entry an #inclusion at that line should
      precede.  */
-  new = new_source_file (source->table, included);
+  new = new_source_file (source->table, included_fullname);
   new->included_by = source;
   new->included_at_line = line;
   new->next_included = *link;
@@ -501,22 +501,22 @@ struct macro_source_file *
 macro_lookup_inclusion (struct macro_source_file *source, const char *name)
 {
   /* Is SOURCE itself named NAME?  */
-  if (filename_cmp (name, source->filename) == 0)
+  if (filename_cmp (name, source->fullname) == 0)
     return source;
 
   /* The filename in the source structure is probably a full path, but
      NAME could be just the final component of the name.  */
   {
     int name_len = strlen (name);
-    int src_name_len = strlen (source->filename);
+    int src_name_len = strlen (source->fullname);
 
     /* We do mean < here, and not <=; if the lengths are the same,
        then the filename_cmp above should have triggered, and we need to
        check for a slash here.  */
     if (name_len < src_name_len
-        && IS_DIR_SEPARATOR (source->filename[src_name_len - name_len - 1])
+        && IS_DIR_SEPARATOR (source->fullname[src_name_len - name_len - 1])
         && filename_cmp (name,
-			 source->filename + src_name_len - name_len) == 0)
+			 source->fullname + src_name_len - name_len) == 0)
       return source;
   }
 
@@ -733,8 +733,8 @@ check_for_redefinition (struct macro_source_file *source, int line,
 	  complaint (&symfile_complaints,
 		     _("macro `%s' redefined at %s:%d; "
 		       "original definition at %s:%d"),
-		     name, source->filename, line,
-		     found_key->start_file->filename, found_key->start_line);
+		     name, source->fullname, line,
+		     found_key->start_file->fullname, found_key->start_line);
         }
 
       return found_key;
@@ -857,8 +857,8 @@ macro_undef (struct macro_source_file *source, int line,
                          _("macro '%s' is #undefined twice,"
                            " at %s:%d and %s:%d"),
                          name,
-                         source->filename, line,
-                         key->end_file->filename, key->end_line);
+                         source->fullname, line,
+                         key->end_file->fullname, key->end_line);
             }
 
           /* Whether or not we've seen a prior #undefinition, wipe out
@@ -884,7 +884,7 @@ macro_undef (struct macro_source_file *source, int line,
    when needed.  */
 
 static struct macro_definition *
-fixup_definition (const char *filename, int line, struct macro_definition *def)
+fixup_definition (const char *fullname, int line, struct macro_definition *def)
 {
   static char *saved_expansion;
 
@@ -898,7 +898,7 @@ fixup_definition (const char *filename, int line, struct macro_definition *def)
     {
       if (def->argc == macro_FILE)
 	{
-	  saved_expansion = macro_stringify (filename);
+	  saved_expansion = macro_stringify (fullname);
 	  def->replacement = saved_expansion;
 	}
       else if (def->argc == macro_LINE)
@@ -918,7 +918,7 @@ macro_lookup_definition (struct macro_source_file *source,
   splay_tree_node n = find_definition (name, source, line);
 
   if (n)
-    return fixup_definition (source->filename, line,
+    return fixup_definition (source->fullname, line,
 			     (struct macro_definition *) n->value);
   else
     return 0;
@@ -963,7 +963,7 @@ foreach_macro (splay_tree_node node, void *arg)
   struct macro_for_each_data *datum = (struct macro_for_each_data *) arg;
   struct macro_key *key = (struct macro_key *) node->key;
   struct macro_definition *def
-    = fixup_definition (key->start_file->filename, key->start_line,
+    = fixup_definition (key->start_file->fullname, key->start_line,
 			(struct macro_definition *) node->value);
 
   (*datum->fn) (key->name, def, key->start_file, key->start_line,
@@ -991,7 +991,7 @@ foreach_macro_in_scope (splay_tree_node node, void *info)
   struct macro_for_each_data *datum = (struct macro_for_each_data *) info;
   struct macro_key *key = (struct macro_key *) node->key;
   struct macro_definition *def
-    = fixup_definition (datum->file->filename, datum->line,
+    = fixup_definition (datum->file->fullname, datum->line,
 			(struct macro_definition *) node->value);
 
   /* See if this macro is defined before the passed-in line, and
diff --git a/gdb/macrotab.h b/gdb/macrotab.h
index 92f1656..459b88b 100644
--- a/gdb/macrotab.h
+++ b/gdb/macrotab.h
@@ -126,7 +126,7 @@ struct macro_source_file
   struct macro_table *table;
 
   /* A source file --- possibly a header file.  */
-  const char *filename;
+  const char *fullname;
 
   /* The location we were #included from, or zero if we are the
      compilation unit's main source file.  */
@@ -173,19 +173,19 @@ struct macro_table *new_macro_table (struct obstack *obstack,
 void free_macro_table (struct macro_table *table);
 
 
 /* Set FILENAME as the main source file of TABLE.  Return a source
    file structure describing that file; if we record the #definition
-   of macros, or the #inclusion of other files into FILENAME, we'll
+   of macros, or the #inclusion of other files into FULLNAME, we'll
    use that source file structure to indicate the context.
 
    The "main source file" is the one that was given to the compiler;
    all other source files that contributed to the compilation unit are
    #included, directly or indirectly, from this one.
 
-   The macro table makes its own copy of FILENAME; the caller is
-   responsible for freeing FILENAME when it is no longer needed.  */
+   The macro table makes its own copy of FULLNAME; the caller is
+   responsible for freeing FULLNAME when it is no longer needed.  */
 struct macro_source_file *macro_set_main (struct macro_table *table,
-                                          const char *filename);
+                                          const char *fullname);
 
 
 /* Return the main source file of the macro table TABLE.  */
@@ -199,18 +199,19 @@ void macro_allow_redefinitions (struct macro_table *table);
 
 /* Record a #inclusion.
    Record in SOURCE's macro table that, at line number LINE in SOURCE,
-   we #included the file INCLUDED.  Return a source file structure we
-   can use for symbols #defined or files #included into that.  If we've
-   already created a source file structure for this #inclusion, return
-   the same structure we created last time.
+   we #included the file INCLUDED_FULLNAME.  Return a source file
+   structure we can use for symbols #defined or files #included into
+   that.  If we've already created a source file structure for this
+   #inclusion, return the same structure we created last time.
 
    The first line of the source file has a line number of 1, not 0.
 
-   The macro table makes its own copy of INCLUDED; the caller is
-   responsible for freeing INCLUDED when it is no longer needed.  */
+   The macro table makes its own copy of INCLUDED_FULLNAME; the caller
+   is responsible for freeing INCLUDED_FULLNAME when it is no longer
+   needed.  */
 struct macro_source_file *macro_include (struct macro_source_file *source,
                                          int line,
-                                         const char *included);
+                                         const char *included_fullname);
 
 /* Define any special macros, like __FILE__ or __LINE__.  This should
    be called once, on the main source file.  */
@@ -173,19 +173,19 @@ struct macro_table *new_macro_table (struct obstack *obstack,
 
 
-/* Set FILENAME as the main source file of TABLE.  Return a source
+/* Set FULLNAME as the main source file of TABLE.  Return a source
    file structure describing that file; if we record the #definition


hooks/post-receive
--
Repository for Project Archer.


             reply	other threads:[~2012-12-25 17:00 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2012-12-25 17:00 jkratoch [this message]
2012-12-27 15:04 jkratoch
2013-01-01 16:47 jkratoch

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20121225170010.18767.qmail@sourceware.org \
    --to=jkratoch@sourceware.org \
    --cc=archer-commits@sourceware.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).